@@ -36,7 +36,7 @@ _ = i18n.language.ugettext
 ## Sets the MAEMO alarm
 ###########################################################################
 def SetAlarm():
-    if(data.demo==False): #We are on a N900
+    if(data.DeviceIsN900==True): #We are on a N900
         event = alarm.Event()
         event.appid = 'SleepAnalyser'
         txt=_('Wake up (SleepAnalyser)')
@@ -72,7 +72,7 @@ def SetAlarm():
 ###########################################################################
 def delete_all_preexisting_Alarms():
     print "* Search and delete all alarms from SleepAnalyser"
-    if(data.demo==False): #We are on a N900
+    if(data.DeviceIsN900==True): #We are on a N900
         event = alarm.query_event(0, 0, 0, 0, "") #get list of all set alarm in N900
         i=0
         for e in event:
@@ -97,7 +97,7 @@ def delete_all_preexisting_Alarms():
 ###########################################################################
 def DeleteAlarm():
     if(data.AlarmID!=-1): #there is an old alarm to be deleted
-        if(data.demo==False): #We are on a N900
+        if(data.DeviceIsN900==True): #We are on a N900
             try:
                 event = alarm.get_event(data.AlarmID) #get data of to be deleted alarm
                 alarm.delete_event(data.AlarmID)
@@ -145,17 +145,17 @@ def ProcessAlarm():
                     records.AlarmTime_tuple=time.localtime()#set to now
                     records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple)
 
-                    if(data.Use_WakeUp_Song==True): #Delay alarm, so we can first play wake up song
+                    if(records.Use_WakeUp_Song==True): #Delay alarm, so we can first play wake up song
                         print "* Alarm would be now:", records.AlarmTime_tuple
-                        print "* But wake Up song is enabled, delay alarm for max", data.WakeUp_Song_Duration/60, "minutes"
-                        records.AlarmTime_seconds=min(records.AlarmTime_seconds+data.WakeUp_Song_Duration, records.AlarmTimeWindowEnd_seconds) #add delay time, but max until alarm time window
+                        print "* But wake Up song is enabled, delay alarm for max", records.WakeUp_Song_Duration/60, "minutes"
+                        records.AlarmTime_seconds=min(records.AlarmTime_seconds+records.WakeUp_Song_Duration, records.AlarmTimeWindowEnd_seconds) #add delay time, but max until alarm time window
                         records.AlarmTime_tuple=Seconds2Tuple(records.AlarmTime_seconds)
-                        data.WakeUp_SongIsActive=True
+                        records.WakeUp_SongIsActive=True
                         records.WakeUp_Song_Start_tuple=Seconds2Tuple(now)
                         print "* Delay alarm until:", records.AlarmTime_tuple
 
                         print "** Play wake up song"
-                        PlaySong(data.WakeUp_Song_Volume, data.WakeUp_Song)
+                        PlaySong(records.WakeUp_Song_Volume, records.WakeUp_Song)
 
                     print "*", strftime("%x %X"), "ProcessAlarm => SetAlarm" #for log file
                     SetAlarm() #set alarm to go off now (or with wake up song delay)
@@ -177,11 +177,11 @@ def ProcessAlarm():
 ## Checks if it is time to start the ucid dream song
 ###########################################################################
 def ProcessLucid_Dream(): #Lucid dream option
-    if(data.Use_Lucid_Dream_Song==True and data.Lucid_Dream_SongIsActive==False):
+    if(records.Use_Lucid_Dream_Song==True and data.Lucid_Dream_SongIsActive==False):
         GenerateStatisticData()
 #        print records.arrStatData[1][2], records.arrStatData[2][2]
-        if(records.arrStatData[1][2] >= data.Lucid_Dream_Song_Delay or records.arrStatData[2][2] >= data.Lucid_Dream_Song_Delay):
+        if(records.arrStatData[1][2] >= records.Lucid_Dream_Song_Delay or records.arrStatData[2][2] >= records.Lucid_Dream_Song_Delay):
             data.Lucid_Dream_SongIsActive=True
             records.Lucid_Dream_Song_Start_tuple=time.localtime() #now
             print "Play Lucid dream song"
-            PlaySong(data.Lucid_Dream_Song_Volume, data.Lucid_Dream_Song)
+            PlaySong(records.Lucid_Dream_Song_Volume, data.Lucid_Dream_Song)
\ No newline at end of file
