@@ -29,7 +29,7 @@ _ = i18n.language.ugettext
 ###########################################################################
 def CreateRecordFile(interval):
     #if not on the N900, use another place for the record file
-    if(data.demo==True): data.RecordFolder=data.developmentRecordFolder #folder on devel PC
+    if(data.DeviceIsN900==False): data.RecordFolder=data.developmentRecordFolder #folder on devel PC
     else: data.RecordFolder=data.defaultRecordFolder
 
     print "RecordFolder:",  data.RecordFolder
@@ -104,6 +104,7 @@ def CreateHeader():
         h=h+"\n"+ "Lucid dream song start: Not set"
         h=h+"\n"+ "Lucid dream song: Not set"
         h=h+"\n"+ "Lucid dream song delay: Not set"
+        h=h+"\n"+ "Lucid dream song duration: Not set"
         h=h+"\n"+ "Lucid dream song volume: Not set"
 
 
@@ -288,7 +289,6 @@ def LoadRecord():
                 tmp=file.readline()
                 tmp=string.replace(tmp[:-1], "Lucid dream song start: ",  "")
                 if(tmp=="Not set"):
-                    print "=> Not set"
                     records.Use_Lucid_Dream_Song=False
                     file.readline() #drop line
                     file.readline() #drop line
@@ -458,4 +458,4 @@ def UpdateFileHeader():
 #            ", " +  str(records.arrData[3][i]) + ", " +  str(records.arrData[5][i])
         file.write(d+"\n")
     file.close()
-    if(data.debug==True): print "Wrote",  i +1,  "records into file"
+    if(data.debug==True): print "Wrote",  i +1,  "records into file"
\ No newline at end of file
