@@ -15,6 +15,9 @@ import string
 import ConfigParser
 import os, os.path
 
+import dbus
+from dbus.mainloop.qt import DBusQtMainLoop
+
 import data
 import filter_data #filter
 import records #record data
@@ -43,20 +46,6 @@ def LoadConfig():
     except:
         pass
 
-    try:
-        configFileVersion = config.getint('main', 'configFileVersion')
-    except:
-        configFileVersion=0
-    if(configFileVersion<data.configFileVersion): #config file is old, update some parameters...
-        if(data.configFileVersion==2):
-            QMessageBox.critical(None, "Changes in SleepAnalyser",
-            "There are new functions and changes in SleepAnalyser. Please have a look in the help menu to see what has changed. " + \
-            "Because of the changes some parameters might need adjustment, expecially the trigger level. " + \
-            "You can change them in the configuration dialog.")
-
-    else: #config file up to date
-        pass
-
 
     try:
         data.Sampling_interval = config.getint('main', 'sampling')
@@ -231,8 +220,23 @@ def LoadConfig():
         config.set('main', 'WakeUp_Song_Duration', str(data.WakeUp_Song_Duration))
 
 
+## Add forced configuration changes here
+    try:
+        configFileVersion = config.getint('main', 'configFileVersion')
+    except:
+        configFileVersion=0
+    if(configFileVersion<data.configFileVersion): #config file is old, update some parameters...
+        if(data.configFileVersion<=3):
+            data.Yscale_Movement=data.Yscale_Movement_default
+            config.set('main', 'Yscale_Movement', str(data.Yscale_Movement_default))
 
+            QMessageBox.critical(None, "Changes in SleepAnalyser",
+            "There are new functions and changes in SleepAnalyser. Please have a look in the help menu to see what has changed. " + \
+            "Because of the changes some parameters might need adjustment, expecially the trigger level. " + \
+            "You can change them in the configuration dialog.")
 
+    else: #config file up to date
+        pass
 
 
 
@@ -324,7 +328,7 @@ def Index2Tuple(Index):
 
 
 def SwitchModes(start):
-    if(data.demo==False): #We are on a N900
+    if(data.DeviceIsN900==True): #We are on a N900
         if(data.QuickMode==False):  #only do in normal recording mode
             if(start==True): #start of recording
                 if(data.SwitchedModes==False): #protection so it only gets switched once
@@ -333,6 +337,7 @@ def SwitchModes(start):
                         set_profile(False)
                     if(data.SilentProfile==True): #change to silent profile
                         set_silent(True)
+                    data.PreviousVolume=GetVolume()
 
             else: #end of recording
                 if(data.SwitchedModes==True): #protection so it only gets switched once
@@ -341,6 +346,7 @@ def SwitchModes(start):
                        set_profile(True)
                     if(data.SilentProfile==True and data.demo!=1): #change to general profile
                         set_silent(False)
+                    SetVolume(data.PreviousVolume)
 
 
 
@@ -411,12 +417,24 @@ def set_silent(silent):
 
 
 
-def set_volume(percent):
+def SetVolume(percent):
     cmd="dbus-send --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.set_extension_property string:volume variant:uint32:"+str(percent)
     os.popen(cmd)
 
 
 
+def GetVolume():
+    if(data.DeviceIsN900==True): #we are on a N900
+        bus = dbus.SessionBus()
+        obj = bus.get_object("com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer",
+            "/com/nokia/mafw/renderer/gstrenderer")
+        mafw = dbus.Interface(obj, "com.nokia.mafw.extension")
+        volume = int(mafw.get_extension_property("volume")[1])
+    #    print "volume,", volume
+        return volume
+
+
+
 
 def PlaySong(volume, filename):
     print strftime("%x %X"), "Play", filename, "with volume", volume
@@ -424,7 +442,7 @@ def PlaySong(volume, filename):
     notify_txt=_("Open Song in media player, set volume to ")+ str(volume) + "%"
     notify_cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+notify_txt+"\""
     os.popen(notify_cmd)
-    set_volume(volume)
+    SetVolume(volume)
     b = os.popen(cmd)
     b.close()
 
@@ -453,4 +471,4 @@ def GetSongLength(filename):
 #    t2=1000*(now-data.passed_time2)
 #    print "### ",  str(int(t)), "ms, (",  str(int(t2)), "ms delta): ", text
 #
-#    data.passed_time2 = time.time()
+#    data.passed_time2 = time.time()
\ No newline at end of file
