@@ -31,7 +31,7 @@ except:
 ###########################################################################
 def ReadAccSensor():
     coords=[0, 0, 0]
-    if(data.demo==False):
+    if(data.DeviceIsN900==True):
         for i in range(data.Sample_smoothing):
             f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
             coords_tmp = [int(w) for w in f.readline().split()]
@@ -128,7 +128,6 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
             Yder=0
             Zder=0
             XYZderivation=0
-#        records.arrData[4][i]=min(XYZderivation*data.Yscale_Movement,  data.Ysize-17) #cut off if higher than graph border
         records.arrData[4][i]=abs(XYZderivation-data.derivation_offset)
 
 #    for i in range(0, min(records.Index-data.Derivation, 200)): records.arrData[4][i]=20 #debug
@@ -195,8 +194,8 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 #        if(data.run==False):  #only draw background for sleep levels when recording is finished
         paint.setPen(QtGui.QColor(data.GraphBackground2))
         paint.setBrush(QtGui.QColor(data.GraphBackground2))
-        h1=(data.Ysize-(data.Deep_Sleep_Level*data.Yscale_Movement/2))
-        h2=(data.Ysize-(data.Light_Sleep_Level*data.Yscale_Movement/2))
+        h1=(data.Ysize-(data.Deep_Sleep_Level*data.Yscale_Movement/40))
+        h2=(data.Ysize-(data.Light_Sleep_Level*data.Yscale_Movement/40))
         paint.drawRect(1, h1-6, records.MaxArrayDataLen-2, h2-h1+2)
 
 
@@ -350,7 +349,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             x=i/Xscale
             if(peak==""): peak=0 #temporary bugfix
 #            print peak, data.Yscale_Movement, data.Ysize
-            h=min(peak*data.Yscale_Movement/2,  data.Ysize-17) #cut off if higher than graph border
+            h=min(peak*data.Yscale_Movement/40,  data.Ysize-17) #cut off if higher than graph border
             paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
 
 
@@ -360,8 +359,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         if(ShowFiltered==True):
             pen=QtGui.QPen()
 
-#            records.arrData[6][records.Index-data.Derivation-Xscale]=records.arrData[6][records.Index-data.Derivation-Xscale-1] #fix for last entry
-
             #filling
             pen.setColor(QtGui.QColor(19, 54, 255, 150))
             pen.setWidth(1)
@@ -384,17 +381,8 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 paint.drawLine(x, y0,       x+1, y1)
 
 
-
-
-
-
-
-
-
-
        #Lucid dream option
         if(records.Use_Lucid_Dream_Song==True and records.Lucid_Dream_Song_Start_tuple!=-1):
-            PrintRecordData(False)
             paint.setBrush(QtGui.QColor(data.Lucid_Dream_Color))
             paint.setPen(QtGui.QColor(data.Lucid_Dream_Color))
             x0=Tuple2Index(records.Lucid_Dream_Song_Start_tuple)-data.Derivation*Xscale
@@ -404,17 +392,11 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             x01=(x1-GraphStart_index)/Xscale
             y=20
             paint.drawPolygon(QPointF(x00, y-4), QPointF(x00, y+4), QPointF(x00+4, y))
-            paint.drawLine(x00, y, x01, y)
-
-
-
-
-
+            paint.drawRect(x00,  y-1,  x01-x00,  2)
 
 
        #WakeUp option
         if(records.Use_WakeUp_Song==True and records.WakeUp_Song_Start_tuple!=-1):
-            PrintRecordData(False)
             paint.setBrush(QtGui.QColor(data.WakeUp_Color))
             paint.setPen(QtGui.QColor(data.WakeUp_Color))
             x0=Tuple2Index(records.WakeUp_Song_Start_tuple)-data.Derivation*Xscale
@@ -424,14 +406,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             x01=(x1-GraphStart_index)/Xscale
             y=20
             paint.drawPolygon(QPointF(x00, y-4), QPointF(x00, y+4), QPointF(x00+4, y))
-            paint.drawLine(x00, y, x01, y)
-
-
-
-
-
-
-
+            paint.drawRect(x00,  y-1,  x01-x00,  2)
 
 
        #ALARM VISUALISATION
@@ -523,7 +498,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
 
 
-        #show parameters
+        #show parameters (for debugging)
         paint.setFont(QtGui.QFont('Decorative', 8))
         paint.setPen(QtGui.QColor("gray"))
         paint.drawText(data.GraphBitMapLen-70, data.Ysize+12, str(data.Yscale_Movement)+", "+str(data.Yscale_Sleep_Pattern)+", "+str(data.Yoffset_Sleep_Pattern)) #settings (for debbigging)
@@ -582,7 +557,7 @@ def MakeNoise_if_over_trigger(peak):
         if((records.Index-data.Derivation)>data.last_beep): #quick mode for testing but only once per move
             if(data.debug==True): print "Beep"
             data.last_beep=records.Index
-            if(data.demo==False): #make beep for testing movement
+            if(data.DeviceIsN900==True): #make beep for testing movement
                 b = os.popen("pacat --channels=2 /usr/share/sounds/ui-default_beep.wav")
                 b.close()
             print "Beep"
