@@ -10,6 +10,8 @@ from PyQt4.QtGui import *
 
 import data
 
+from functions_record import *
+
 
 
 #Here is the installation of the hook. Each time a untrapped/unmanaged exception will
@@ -42,8 +44,12 @@ def error():
 
 #A small Qt Dialog
 def ErrorReportDialog(trace,txt_email=None):
-    print "-----------------------------------------------------------------------------\n", trace
+    print "-----------------------------------------------------------------------------\n"
 #    item, ok = QInputDialog.getItem(None, 'Select voice type', "", "aabcde", 0, False)
+    print "ERROR!!!"
+    PrintRecordData()
+
+    print trace
 
     txt=string.replace(trace, "  File \"/opt/SleepAnalyser/", "\"")
     arr=txt.split("\n")
@@ -54,6 +60,7 @@ def ErrorReportDialog(trace,txt_email=None):
     QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt) #Max 11 lines in dialog!
 #    r=QInputDialog.getText(None,  "Add Note",  trace,  QLineEdit.Normal,  "---\nlll\nkkk")
 
+
     quit() #quit application
 
 
